q1ss.ap.sequence
================

.. automodule:: q1ss.ap.sequence

SeqAP
-----

.. autoclass:: q1ss.ap.sequence.SeqAP
    :show-inheritance:
    :members:
    :special-members: __new__, __getitem__

SeqAPData
---------

.. autoclass:: q1ss.ap.sequence.SeqAPData
    :show-inheritance:
    :members:
    :special-members: __new__

SeqAPMatrixGen
--------------

.. autoclass:: q1ss.ap.sequence.SeqAPMatrixGen
    :show-inheritance:
    :members:
    :special-members: __new__, __call__
